@@ -9,6 +9,9 @@
 #' @importFrom grDevices adjustcolor rainbow
 #' @importFrom graphics abline boxplot legend lines par plot points segments text
 #' @importFrom stats coef cor lm na.omit sd
+#' @author Fred Viole, OVVO Financial Systems
+#' @references Viole, F. and Nawrocki, D. (2013) "Nonlinear Nonparametric Statistics: Using Partial Moments"
+#' \url{http://amzn.com/1490523995}
 #' @examples
 #' set.seed(123)
 #' x<-rnorm(100)
@@ -28,6 +31,9 @@ LPM<- function(degree,target,variable)
 #' @param variable Variable
 #' @return UPM of variable
 #' @keywords partial moments
+#' @author Fred Viole, OVVO Financial Systems
+#' @references Viole, F. and Nawrocki, D. (2013) "Nonlinear Nonparametric Statistics: Using Partial Moments"
+#' \url{http://amzn.com/1490523995}
 #' @examples
 #' set.seed(123)
 #' x<-rnorm(100)
@@ -50,14 +56,17 @@ UPM<- function(degree,target,variable){
 #' @param variable2 Variable 2
 #' @return Co-UPM of two variables
 #' @keywords partial moments
+#' @author Fred Viole, OVVO Financial Systems
+#' @references Viole, F. and Nawrocki, D. (2013) "Nonlinear Nonparametric Statistics: Using Partial Moments"
+#' \url{http://amzn.com/1490523995}
 #' @examples
 #' set.seed(123)
 #' x<-rnorm(100); y<-rnorm(100)
-#' \dontrun{Co_UPM(0,mean(x),mean(y),x,y)}
+#' \dontrun{Co.UPM(0,mean(x),mean(y),x,y)}
 #' @export
 
 
-Co_UPM<- function(degree,target1,target2,variable1,variable2){
+Co.UPM<- function(degree,target1,target2,variable1,variable2){
   output <- vector("numeric", length(variable1))
   for (i in 1:length(variable1))
   {
@@ -66,7 +75,7 @@ Co_UPM<- function(degree,target1,target2,variable1,variable2){
       output[i]<- (((variable1[i]-target1)^degree)*((variable2[i]-target2)^degree))
   }
 
-  return(Co_UPM=sum(output)/length(variable1))
+  return(sum(output)/length(variable1))
 
 }
 
@@ -81,13 +90,16 @@ Co_UPM<- function(degree,target1,target2,variable1,variable2){
 #' @param variable2 Variable 2
 #' @return Co-LPM of two variables
 #' @keywords partial moments
+#' @author Fred Viole, OVVO Financial Systems
+#' @references Viole, F. and Nawrocki, D. (2013) "Nonlinear Nonparametric Statistics: Using Partial Moments"
+#' \url{http://amzn.com/1490523995}
 #' @examples
 #' set.seed(123)
 #' x<-rnorm(100); y<-rnorm(100)
-#' \dontrun{Co_LPM(0,mean(x),mean(y),x,y)}
+#' \dontrun{Co.LPM(0,mean(x),mean(y),x,y)}
 #' @export
 
-Co_LPM<- function(degree,target1,target2,variable1,variable2){
+Co.LPM<- function(degree,target1,target2,variable1,variable2){
 
   output <- vector("numeric", length(variable1))
   for (i in 1:length(variable1))
@@ -112,13 +124,16 @@ Co_LPM<- function(degree,target1,target2,variable1,variable2){
 #' @param variable2 Variable 2
 #' @return Divergent LPM of two variables
 #' @keywords partial moments
+#' @author Fred Viole, OVVO Financial Systems
+#' @references Viole, F. and Nawrocki, D. (2013) "Nonlinear Nonparametric Statistics: Using Partial Moments"
+#' \url{http://amzn.com/1490523995}
 #' @examples
 #' set.seed(123)
 #' x<-rnorm(100); y<-rnorm(100)
-#' \dontrun{D_LPM(0,mean(x),mean(y),x,y)}
+#' \dontrun{D.LPM(0,mean(x),mean(y),x,y)}
 #' @export
 
-D_LPM<- function(degree_n,degree_q,target1,target2,variable1,variable2){
+D.LPM<- function(degree_n,degree_q,target1,target2,variable1,variable2){
 
   output <- vector("numeric", length(variable1))
   for (i in 1:length(variable1))
@@ -143,22 +158,25 @@ D_LPM<- function(degree_n,degree_q,target1,target2,variable1,variable2){
 #' @param target2 Typically set to mean of Variable 2, but does not have to be
 #' @param variable1 Variable 1
 #' @param variable2 Variable 2
-#' @return Divergent UPM of two variable
+#' @return Divergent UPM of two variables
 #' @keywords partial moments
+#' @author Fred Viole, OVVO Financial Systems
+#' @references Viole, F. and Nawrocki, D. (2013) "Nonlinear Nonparametric Statistics: Using Partial Moments"
+#' \url{http://amzn.com/1490523995}
 #' @examples
 #' set.seed(123)
 #' x<-rnorm(100); y<-rnorm(100)
-#' \dontrun{D_UPM(0,mean(x),mean(y),x,y)}
+#' \dontrun{D.UPM(0,mean(x),mean(y),x,y)}
 #' @export
 
-D_UPM<- function(degree_n,degree_q,target1,target2,variable1,variable2){
+D.UPM<- function(degree_n,degree_q,target1,target2,variable1,variable2){
 
   output <- vector("numeric", length(variable1))
   for (i in 1:length(variable1))
   {
     if ((variable1[i]<target1)*(variable2[i]>target2)==1)
 
-      output[i]<- (((target1-variable1[i])^degree_q)*((variable2[i]-target2)^degree_n))
+      output[i]<- (((target1-variable1[i])^degree_n)*((variable2[i]-target2)^degree_q))
   }
   return(c(sum(output)/length(variable1)))
 }
